from imports import *
pdf_path = "/srv/media/thedailydialectics/pdfs/cancer/cannabis/test-cancer/test-cancer.pdf"
pline = DocumentPipeline(pdf_path)
pline.run()
#generate_pdf_manifest(pdf_path = pdf_path,
##base_url=ROOT_URL,
##media_root=MEDIA_ROOT_DIR,
##pdfs_public_url=PDFS_PUBLIC_URL)

text = """ Datasets were or 2014 Cancer Ther Mol 1312 December 2958
for normality by the ShapiroWilk and differ- testing, between variable determined control and groups ences Paired analysis of by appropriate using variance. tests difference. determine used then further to were any All from data of three consisted least sets at separate experiments. Results CBD and THC reduce the number of glioma cells when used alone human lines cell glioma Two representing various at of selected this multistep malignancy for stages were the cell line GL261 investigation, murine syngeneic as was the C57BL6 of The CBD and THC activities to mouse. assessed these both cells P their form in in were pure g purity 96 and less formulation refined designated ina the botanical that drug substance BDS typically z as con- tained between and ww the of specific 60 72 2 can- the nabinoid. BDS of The made remaining z mass up was  mainly cannabinoids, cannabi- CBG and other such of as other g material. plant CBC, and chromene 8 There reductions dose-dependent cell in num- were 2 bers cell three all lines cultured the cannabinoids with in Es human 1A. of the T98G Generally, Fig. lines, cell two a the with GBM sensitive to treatments, con- more was Fl by cell numbers reduce required 50 centrations to 2 umolL. Flow being approximately IC59 cytometric 10 analysis the culturing that revealed cells CBD with 3 or  changes profile the caused THC significant DNA to no Fig. drug involved element 2B, RS activity suggesting an 8 blot of analysis showed of caspase-3 cytostasis. Western S that following of induction minimal the apoptosis was g THC and however, CBD with dose-depen- treatment a  of LC3Bii indicated the the dent levels increase in g induction of autophagy Closer Fig. 3D. examination g cannabinoids the identified of ICso-values for the a  divergence of and of the the forms. BDS In P activities 5 the lines tested, cell all CBD three active in more was g This T98G cells. this form, the in P apparent most was 3 the the cannabinoids form BDS that in minor suggests namely compound, the of CBC 5, THC and 4, 3 8 have CBG 1, interfered with activity its may  Conversely, THC Fig. the of 1B. activity greater was contained, BDS the which form, in its extra among the CBC cannabinoids, CBG 2, and constituents, that 1, these indicating aid components extra may THC action. its in THC and numbers reduce together CBD cell to act effect also combining of assessed the the We two com- of the cell lines glioma pounds median by in our means effect with THC CBD combining model. required This at CI ICs9s, equivalent and their of that ratios computing a the of signified These values interaction. nature any were indicating for lines, the cell hyper- below generally 1 a effect combining CBD with THC Fig. 2A. additive when between BDS and the of combination Each P permutation Molecular Cancer Therapeutics"""

summary = get_summary(text=text)
input(summary)
